@@ -16,15 +16,15 @@ from utils.proxies import sign, auth, proxy
 from typing import List, Optional, Dict
 
 
-print(f"os: {os.path.dirname(os.path.abspath(os.path.curdir))}")
-print(f"sys: {sys.path[0]}")
+
 # print(os.path.abspath(__file__)
 
 # logger level
 logger.remove()
-logger.add(sys.stdout, level='DEBUG')
-
+logger.add(sys.stdout, level='INFO')
 
+logger.debug(f"os: {os.path.dirname(os.path.abspath(os.path.curdir))}")
+logger.debug(f"sys: {sys.path[0]}")
 
 
 class BaseSpider(object):
@@ -289,7 +289,7 @@ class BaseBSpider():
 
 if __name__ == "__main__":
     print("a")
-    spider = Base()
+    spider = BaseSpider()
     res = spider.search("海南浪淘沙网络科技有限公司")
     print(res)
     # spider.start_request(["深圳市黑石互娱科技有限公司 企查查"], 0, 1)
