@@ -1,7 +1,11 @@
 from typing import Optional, List, Dict
 import datetime
+import sys, os
 sys.path.append(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
-from .basic_search_engine_spider import EngineBaseSpdier
+try:
+    from basic_search_engine_spider import EngineBaseSpdier
+except:
+    from .basic_search_engine_spider import EngineBaseSpdier 
 from utils.proxies import sign, auth, proxy
 from models.result import SearchItem
 from typing import List
@@ -10,8 +14,6 @@ from urllib import response
 import requests
 from pprint import pprint
 from loguru import logger
-import sys
-import os
 from queue import Queue
 import re
 from tqdm import tqdm
@@ -89,7 +91,8 @@ class BingSpider():
         self.params_queue = Queue()
         self.url_queue = Queue()
         self.item_queue = Queue()
-        self.total_num_proxy = 0
+        self.total_count_no_proxy = 0
+        self.total_count_proxy = 0
         
 
     def start_params(self, keyword_list: List, start_page: int = 0, end_page: int = 0):
@@ -117,14 +120,16 @@ class BingSpider():
                 try:
                     response = requests.get(
                         url=self.url, headers=self.headers, params=self.params, timeout=10, proxies=proxies, verify=False, allow_redirects=False)
+                    self.total_count_proxy += 1
+                    logger.debug(f"使用代理请求，目前已使用代理{self.total_count_proxy}次")
                 except Exception as e:
-                    self.total_num_proxy += 1
-                    logger.warning(f"代理请求失败，使用无代理重试，目前已使用无代理{self.total_num_proxy}次，错误信息：{e}")
+                    self.total_count_no_proxy += 1
+                    logger.warning(f"代理请求失败，使用无代理重试，目前已使用无代理{self.total_count_no_proxy}次，错误信息：{e}")
                     response = requests.get(
                         url=self.url, headers=self.headers, params=self.params, timeout=10)
                     
             else:
-                logger.debug(f"使用无代理请求, 目前已经使用无代理{self.total_num_proxy}次")
+                logger.debug(f"使用无代理请求, 目前已经使用无代理{self.total_count_no_proxy}次")
                 response = requests.get(
                     url=self.url, headers=self.headers, params=self.params, timeout=10)
         except Exception as e:
@@ -342,6 +347,11 @@ class BingNewsSpider(EngineBaseSpdier):
         item_list = []
         doc = HTML(response.text)
         res = doc.xpath('//div[contains(@class,"news-card")]')
+        # title_list = [item.xpath('.//a[@class="title"]/text()')[0] for item in res]
+        # print(title_list)
+        res = res[::2]
+        title_list = [item.xpath('.//a[@class="title"]/text()')[0] for item in res]
+        logger.debug(f"title list {title_list}")
         crawltime = datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S")
         page_num = kwargs.get("page_num")
         keyword = kwargs.get("keyword")
@@ -379,6 +389,7 @@ class BingNewsSpider(EngineBaseSpdier):
         for i in range(start_page, end_page):
 
             # 代理判断
+            proxy = kwargs.get("proxy")
             # 无代理
             if proxy == {} or proxy == None:
                 if kwargs.get('cookie') != None and kwargs.get('cookie') != {}:
@@ -437,6 +448,6 @@ if __name__ == "__main__":
     }
     kwargs = {}
     kwargs["cookie"] = cookies
-    res = spider.search("原神 舆情", 0, 1, **kwargs)
+    res = spider.search("维护国家主权和领土完整的能力", 0, 2, **kwargs)
     for item in res:
-        pprint(item.__dict__)
+        pprint(item.__dict__['title'])
